==> paoding-rose-elasticsearch-1.2-sources.jar: cn/zhangfusheng/elasticsearch/config/ElasticSearchConfigConfiguration.java <==
package cn.zhangfusheng.elasticsearch.config;

import cn.zhangfusheng.elasticsearch.annotation.EnablePaodingRoseElasticSearch;
import org.elasticsearch.client.RestHighLevelClient;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.BeanFactoryAware;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ImportAware;
import org.springframework.context.annotation.Role;
import org.springframework.core.annotation.AnnotationAttributes;
import org.springframework.core.type.AnnotationMetadata;

/**
 * @author fusheng.zhang
 * @date 2022-04-20 12:18:35
 */
public class ElasticSearchConfigConfiguration implements ImportAware, BeanFactoryAware {

    private BeanFactory beanFactory;

    @Override
    public void setImportMetadata(AnnotationMetadata importMetadata) {
        AnnotationAttributes.fromMap(
                importMetadata.getAnnotationAttributes(EnablePaodingRoseElasticSearch.class.getName()));
    }

    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public ElasticSearchConfigOperationSourceAdvisor beanFactoryTransactionalOperationSourceAdvisor() {
        RestHighLevelClient restHighLevelClient = beanFactory.getBean(RestHighLevelClient.class);
        return new ElasticSearchConfigOperationSourceAdvisor(restHighLevelClient);
    }

    @Override
    public void setBeanFactory(BeanFactory beanFactory) throws BeansException {
        this.beanFactory = beanFactory;
    }
}

==> paoding-rose-elasticsearch-1.6-sources.jar: cn/zhangfusheng/elasticsearch/config/ElasticSearchConfigConfiguration.java <==
package cn.zhangfusheng.elasticsearch.config;

import cn.zhangfusheng.elasticsearch.annotation.EnablePaodingRoseElasticSearch;
import cn.zhangfusheng.elasticsearch.template.ElasticSearchRestTemplate;
import org.elasticsearch.client.RestHighLevelClient;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.ImportAware;
import org.springframework.context.annotation.Role;
import org.springframework.core.annotation.AnnotationAttributes;
import org.springframework.core.type.AnnotationMetadata;

/**
 * @author fusheng.zhang
 * @date 2022-04-20 12:18:35
 */
@ComponentScan("cn.zhangfusheng.elasticsearch")
public class ElasticSearchConfigConfiguration implements ImportAware {

    @Override
    public void setImportMetadata(AnnotationMetadata importMetadata) {
        AnnotationAttributes.fromMap(
                importMetadata.getAnnotationAttributes(EnablePaodingRoseElasticSearch.class.getName()));
    }

    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public ElasticSearchRestTemplate elasticSearchRestTemplate(RestHighLevelClient restHighLevelClient) {
        return new ElasticSearchRestTemplate(restHighLevelClient);
    }

    @Bean
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    public ElasticSearchConfigOperationSourceAdvisor beanFactoryTransactionalOperationSourceAdvisor(RestHighLevelClient restHighLevelClient) {
        return new ElasticSearchConfigOperationSourceAdvisor(restHighLevelClient);
    }

}
